@@ -421,7 +421,9 @@ class dyagram:
 
         try:
             self.log.info("GETTING DEVICE TYPE IN EIGRP NEIGHBORS SSH")
+            time.sleep(10)
             os = self.get_device_type(device)
+            self.log.info("GOT DEVICE TYPE  FROM get_device_type func IN EIGRP NEIGHBORS SSH_top")
             if os:
                 self.log.info("GOT DEVICE TYPE  FROM get_device_type func IN EIGRP NEIGHBORS SSH")
                 nm_args = self.netmiko_args_template.copy()
